@@ -21,7 +21,7 @@ def get_dataset(dataset=None):
     based on a user-provided label. In the future, we can add https endpoints
     to retrieve online datasets.
     """
-    dicom_cookies = os.path.join(data_base, "data", "dicom-cookies")
+    dicom_cookies = os.path.join(data_base, "dicom-cookies")
 
     if not os.path.exists(dicom_cookies):
         raise ValueError("install deid data with `pip install deid-data`")
